@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -38,22 +38,20 @@
 
 
 ZIP_EXTERN const char *
-zip_get_name(zip_t *za, zip_uint64_t idx, zip_flags_t flags)
-{
+zip_get_name(zip_t *za, zip_uint64_t idx, zip_flags_t flags) {
     return _zip_get_name(za, idx, flags, &za->error);
 }
 
 
 const char *
-_zip_get_name(zip_t *za, zip_uint64_t idx, zip_flags_t flags, zip_error_t *error)
-{
+_zip_get_name(zip_t *za, zip_uint64_t idx, zip_flags_t flags, zip_error_t *error) {
     zip_dirent_t *de;
     const zip_uint8_t *str;
 
-    if ((de=_zip_get_dirent(za, idx, flags, error)) == NULL)
+    if ((de = _zip_get_dirent(za, idx, flags, error)) == NULL)
 	return NULL;
 
-    if ((str=_zip_string_get(de->filename, NULL, flags, error)) == NULL)
+    if ((str = _zip_string_get(de->filename, NULL, flags, error)) == NULL)
 	return NULL;
 
     return (const char *)str;
