@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -36,16 +36,15 @@
 
 
 zip_int64_t
-zip_source_read(zip_source_t *src, void *data, zip_uint64_t len)
-{
+zip_source_read(zip_source_t *src, void *data, zip_uint64_t len) {
     zip_uint64_t bytes_read;
     zip_int64_t n;
 
     if (src->source_closed) {
-        return -1;
+	return -1;
     }
     if (!ZIP_SOURCE_IS_OPEN_READING(src) || len > ZIP_INT64_MAX || (len > 0 && data == NULL)) {
-        zip_error_set(&src->error, ZIP_ER_INVAL, 0);
+	zip_error_set(&src->error, ZIP_ER_INVAL, 0);
 	return -1;
     }
 
@@ -57,10 +56,14 @@ zip_source_read(zip_source_t *src, void *data, zip_uint64_t len)
 	return 0;
     }
 
+    if (len == 0) {
+      return 0;
+    }
+
     bytes_read = 0;
     while (bytes_read < len) {
 	if ((n = _zip_source_call(src, (zip_uint8_t *)data + bytes_read, len - bytes_read, ZIP_SOURCE_READ)) < 0) {
-            src->had_read_error = true;
+	    src->had_read_error = true;
 	    if (bytes_read == 0) {
 		return -1;
 	    }
@@ -82,7 +85,6 @@ zip_source_read(zip_source_t *src, void *data, zip_uint64_t len)
 
 
 bool
-_zip_source_eof(zip_source_t *src)
-{
+_zip_source_eof(zip_source_t *src) {
     return src->eof;
 }
