@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -36,23 +36,22 @@
 
 
 ZIP_EXTERN int
-zip_source_stat(zip_source_t *src, zip_stat_t *st)
-{
+zip_source_stat(zip_source_t *src, zip_stat_t *st) {
     if (src->source_closed) {
-        return -1;
+	return -1;
     }
     if (st == NULL) {
-        zip_error_set(&src->error, ZIP_ER_INVAL, 0);
+	zip_error_set(&src->error, ZIP_ER_INVAL, 0);
 	return -1;
     }
 
     zip_stat_init(st);
-    
+
     if (ZIP_SOURCE_IS_LAYERED(src)) {
-        if (zip_source_stat(src->src, st) < 0) {
-            _zip_error_set_from_source(&src->error, src->src);
-            return -1;
-        }
+	if (zip_source_stat(src->src, st) < 0) {
+	    _zip_error_set_from_source(&src->error, src->src);
+	    return -1;
+	}
     }
 
     if (_zip_source_call(src, st, sizeof(*st), ZIP_SOURCE_STAT) < 0) {
