@@ -40,25 +40,28 @@
 
 #ifdef HAVE_CLONEFILE
 #include <sys/attr.h>
-#include <sys/param.h>
 #include <sys/mount.h>
+#include <sys/param.h>
+#include <unistd.h>
+#elif defined(HAVE_FICLONERANGE)
+#include <linux/fs.h>
+#include <sys/ioctl.h>
 #include <unistd.h>
 #endif
 
 int
-main(int argc, char *argv[])
-{
+main(int argc, char *argv[]) {
 #ifdef HAVE_CLONEFILE
     struct statfs fs;
     struct attrlist attribute_list;
     struct {
-        uint32_t size;
-        vol_capabilities_attr_t capabilities;
+	uint32_t size;
+	vol_capabilities_attr_t capabilities;
     } volume_attributes;
 
     if (statfs(".", &fs) < 0) {
-        fprintf(stderr, "%s: can't get mount point of current directory: %s\n", argv[0], strerror(errno));
-        exit(1);
+	fprintf(stderr, "%s: can't get mount point of current directory: %s\n", argv[0], strerror(errno));
+	exit(1);
     }
 
     /* Not all volumes support clonefile().  A volume can be tested for
@@ -68,16 +71,52 @@ main(int argc, char *argv[])
 
     memset(&attribute_list, 0, sizeof(attribute_list));
     attribute_list.bitmapcount = ATTR_BIT_MAP_COUNT;
-    attribute_list.volattr = ATTR_VOL_INFO|ATTR_VOL_CAPABILITIES;
+    attribute_list.volattr = ATTR_VOL_INFO | ATTR_VOL_CAPABILITIES;
     memset(&volume_attributes, 0, sizeof(volume_attributes));
 
     if (getattrlist(fs.f_mntonname, &attribute_list, &volume_attributes, sizeof(volume_attributes), 0) < 0) {
-        fprintf(stderr, "%s: can't get volume capabilities of '%s': %s\n", argv[0], fs.f_mntonname, strerror(errno));
-        exit(1);
+	fprintf(stderr, "%s: can't get volume capabilities of '%s': %s\n", argv[0], fs.f_mntonname, strerror(errno));
+	exit(1);
     }
 
     if (volume_attributes.capabilities.capabilities[VOL_CAPABILITIES_INTERFACES] & VOL_CAP_INT_CLONE) {
-        exit(0);
+	exit(0);
+    }
+#elif defined(HAVE_FICLONERANGE)
+    char namea[32] = "a.fioclone.XXXXXX";
+    char nameb[32] = "b.fioclone.XXXXXX";
+    int fda, fdb, ret;
+    struct file_clone_range range;
+
+    if ((fda = mkstemp(namea)) < 0) {
+	fprintf(stderr, "can't create temp file a: %s\n", strerror(errno));
+	exit(1);
+    }
+    if ((fdb = mkstemp(nameb)) < 0) {
+	fprintf(stderr, "can't create temp file b: %s\n", strerror(errno));
+	(void)close(fda);
+	(void)remove(namea);
+	exit(1);
+    }
+    if (write(fda, "test\n", 5) < 0) {
+	fprintf(stderr, "can't write temp file a: %s\n", strerror(errno));
+	(void)close(fda);
+	(void)remove(namea);
+	close(fdb);
+	(void)remove(nameb);
+	exit(1);
+    }
+    range.src_fd = fda;
+    range.src_offset = 0;
+    range.src_length = 0;
+    range.dest_offset = 0;
+    ret = ioctl(fdb, FICLONERANGE, &range);
+    (void)close(fda);
+    (void)close(fdb);
+    (void)remove(namea);
+    (void)remove(nameb);
+    if (ret >= 0) {
+	exit(0);
     }
 #endif
 
