@@ -1,6 +1,6 @@
 /*
   fopen_unchanged.c -- test case for adding file and reading from unchanged
-  Copyright (C) 2012 Dieter Baron and Thomas Klausner
+  Copyright (C) 2012-2015 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
   The authors can be contacted at <libzip@nih.at>
@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -31,7 +31,6 @@
   IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-
 
 #include <errno.h>
 #include <stdio.h>
@@ -40,16 +39,14 @@
 
 #include "zip.h"
 
-const char *teststr="This is a test.\n";
-const char *file="teststring.txt";
+const char *teststr = "This is a test.\n";
+const char *file = "teststring.txt";
 
 int
-main(int argc, char *argv[])
-{
+main(int argc, char *argv[]) {
     const char *archive;
-    struct zip *za;
-    struct zip_source *zs;
-    char buf[100];
+    zip_t *za;
+    zip_source_t *zs;
     int err;
 
     if (argc != 2) {
@@ -58,31 +55,35 @@ main(int argc, char *argv[])
     }
 
     archive = argv[1];
-    
-    if ((za=zip_open(archive, ZIP_CREATE, &err)) == NULL) {
-	zip_error_to_str(buf, sizeof(buf), err, errno);
-	fprintf(stderr, "can't open zip archive `%s': %s\n", archive, buf);
+
+    if ((za = zip_open(archive, ZIP_CREATE, &err)) == NULL) {
+	zip_error_t error;
+	zip_error_init_with_code(&error, err);
+	fprintf(stderr, "can't open zip archive '%s': %s\n", archive, zip_error_strerror(&error));
+	zip_error_fini(&error);
 	return 1;
     }
 
-    if ((zs=zip_source_buffer(za, teststr, strlen(teststr), 0)) == NULL) {
+    if ((zs = zip_source_buffer(za, teststr, strlen(teststr), 0)) == NULL) {
 	fprintf(stderr, "can't create zip_source from buffer: %s\n", zip_strerror(za));
 	exit(1);
     }
 
     if (zip_add(za, file, zs) == -1) {
-	zip_source_free(zs);
-	fprintf(stderr, "can't add file `%s': %s\n", file, zip_strerror(za));
+	fprintf(stderr, "can't add file '%s': %s\n", file, zip_strerror(za));
+	(void)zip_source_free(zs);
+	(void)zip_close(za);
 	return 1;
     }
 
     if (zip_fopen(za, file, ZIP_FL_UNCHANGED) == NULL) {
-	fprintf(stderr, "can't zip_fopen file `%s': %s\n", file, zip_strerror(za));
+	fprintf(stderr, "can't zip_fopen file '%s': %s\n", file, zip_strerror(za));
+	(void)zip_discard(za);
 	return 1;
     }
 
     if (zip_close(za) == -1) {
-	fprintf(stderr, "can't close zip archive `%s': %s\n", archive, zip_strerror(za));
+	fprintf(stderr, "can't close zip archive '%s': %s\n", archive, zip_strerror(za));
 	return 1;
     }
 
