@@ -37,20 +37,21 @@
 #include <stdlib.h>
 
 int
-main(int argc, const char *argv[])
-{
+main(int argc, const char *argv[]) {
     char buf[1024];
     int i;
 
+#ifdef HAVE_CRYPTO
     if (!zip_random(buf, sizeof(buf))) {
 	fprintf(stderr, "zip_random returned false\n");
 	exit(1);
     }
-    for (i=0; i<sizeof(buf); i++) {
+    for (i = 0; i < sizeof(buf); i++) {
 	if (buf[i] != 0) {
 	    fprintf(stderr, "non-zero byte found\n");
 	    exit(1);
 	}
     }
+#endif
     exit(0);
 }
