@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -34,11 +34,11 @@
 
 #include "config.h"
 
-#include <sys/stat.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
 #ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
@@ -88,12 +88,11 @@ struct entry {
 
 const char *prg;
 
-#define PROGRAM	"zipcmp"
+#define PROGRAM "zipcmp"
 
 #define USAGE "usage: %s [-hipqtVv] archive1 archive2\n"
 
-char help_head[] =
-    PROGRAM " (" PACKAGE ") by Dieter Baron and Thomas Klausner\n\n";
+char help_head[] = PROGRAM " (" PACKAGE ") by Dieter Baron and Thomas Klausner\n\n";
 
 char help[] = "\n\
   -h       display this help message\n\
@@ -113,15 +112,11 @@ Copyright (C) 2003-2017 Dieter Baron and Thomas Klausner\n\
 #define OPTIONS "hVipqtv"
 
 
-#define BOTH_ARE_ZIPS(a)	(a[0].za && a[1].za)
+#define BOTH_ARE_ZIPS(a) (a[0].za && a[1].za)
 
 static int comment_compare(const char *c1, size_t l1, const char *c2, size_t l2);
-static int compare_list(char * const name[],
-			const void *l[], const zip_uint64_t n[], int size,
-			int (*cmp)(const void *, const void *),
-			int (*checks)(char *const name[2], const void *, const void *),
-			void (*print)(const void *));
-static int compare_zip(char * const zn[]);
+static int compare_list(char *const name[], const void *l[], const zip_uint64_t n[], int size, int (*cmp)(const void *, const void *), int (*checks)(char *const name[2], const void *, const void *), void (*print)(const void *));
+static int compare_zip(char *const zn[]);
 static int ef_compare(char *const name[2], const struct entry *e1, const struct entry *e2);
 static int ef_order(const void *a, const void *b);
 static void ef_print(const void *p);
@@ -141,8 +136,7 @@ int header_done;
 
 
 int
-main(int argc, char * const argv[])
-{
+main(int argc, char *const argv[]) {
     int c;
 
     prg = argv[0];
@@ -152,7 +146,7 @@ main(int argc, char * const argv[])
     paranoid = 0;
     verbose = 1;
 
-    while ((c=getopt(argc, argv, OPTIONS)) != -1) {
+    while ((c = getopt(argc, argv, OPTIONS)) != -1) {
 	switch (c) {
 	case 'i':
 	    ignore_case = 1;
@@ -185,44 +179,43 @@ main(int argc, char * const argv[])
 	}
     }
 
-    if (argc != optind+2) {
+    if (argc != optind + 2) {
 	fprintf(stderr, USAGE, prg);
 	exit(2);
     }
 
-    exit((compare_zip(argv+optind) == 0) ? 0 : 1);
+    exit((compare_zip(argv + optind) == 0) ? 0 : 1);
 }
 
 
 static int
-compare_zip(char * const zn[])
-{
+compare_zip(char *const zn[]) {
     struct archive a[2];
     struct entry *e[2];
     zip_uint64_t n[2];
     int i;
     int res;
 
-    for (i=0; i<2; i++) {
+    for (i = 0; i < 2; i++) {
 	a[i].name = zn[i];
 	a[i].entry = NULL;
 	a[i].nentry = 0;
 	a[i].za = NULL;
 	a[i].comment = NULL;
-	a[i].comment_length =0;
+	a[i].comment_length = 0;
 
 	if (is_directory(zn[i])) {
 #ifndef HAVE_FTS_H
 	    fprintf(stderr, "%s: reading directories not supported\n", prg);
 	    exit(2);
 #else
-	    if (list_directory(zn[i], a+i) < 0)
+	    if (list_directory(zn[i], a + i) < 0)
 		exit(2);
 	    paranoid = 0; /* paranoid checks make no sense for directories, since they compare zip metadata */
 #endif
 	}
 	else {
-	    if (list_zip(zn[i], a+i) < 0)
+	    if (list_zip(zn[i], a + i) < 0)
 		exit(2);
 	}
 	if (a[i].nentry > 0)
@@ -247,7 +240,7 @@ compare_zip(char * const zn[])
 	}
     }
 
-    for (i=0; i<2; i++)
+    for (i = 0; i < 2; i++)
 	if (a[i].za)
 	    zip_close(a[i].za);
 
@@ -265,20 +258,19 @@ compare_zip(char * const zn[])
 
 #ifdef HAVE_FTS_H
 static zip_int64_t
-compute_crc(const char *fname)
-{
+compute_crc(const char *fname) {
     FILE *f;
     uLong crc = crc32(0L, Z_NULL, 0);
     size_t n;
     Bytef buffer[8192];
 
 
-    if ((f=fopen(fname, "r")) == NULL) {
+    if ((f = fopen(fname, "r")) == NULL) {
 	fprintf(stderr, "%s: can't open %s: %s\n", prg, fname, strerror(errno));
 	return -1;
     }
 
-    while ((n=fread(buffer, 1, sizeof(buffer), f)) > 0) {
+    while ((n = fread(buffer, 1, sizeof(buffer), f)) > 0) {
 	crc = crc32(crc, buffer, (unsigned int)n);
     }
 
@@ -296,8 +288,7 @@ compute_crc(const char *fname)
 
 
 static int
-is_directory(const char *name)
-{
+is_directory(const char *name) {
     struct stat st;
 
     if (stat(name, &st) < 0)
@@ -309,21 +300,20 @@ is_directory(const char *name)
 
 #ifdef HAVE_FTS_H
 static int
-list_directory(const char *name, struct archive *a)
-{
+list_directory(const char *name, struct archive *a) {
     FTS *fts;
     FTSENT *ent;
     zip_uint64_t nalloc;
     size_t prefix_length;
 
-    char * const names[2] = { (char *)name, NULL };
+    char *const names[2] = {(char *)name, NULL};
 
 
-    if ((fts = fts_open(names, FTS_NOCHDIR|FTS_LOGICAL, NULL)) == NULL) {
+    if ((fts = fts_open(names, FTS_NOCHDIR | FTS_LOGICAL, NULL)) == NULL) {
 	fprintf(stderr, "%s: can't open directory '%s': %s\n", prg, name, strerror(errno));
 	return -1;
     }
-    prefix_length = strlen(name)+1;
+    prefix_length = strlen(name) + 1;
 
     nalloc = 0;
 
@@ -351,24 +341,24 @@ list_directory(const char *name, struct archive *a)
 	case FTS_F:
 	    if (a->nentry >= nalloc) {
 		nalloc += 16;
-		if (nalloc > SIZE_MAX/sizeof(a->entry[0])) {
+		if (nalloc > SIZE_MAX / sizeof(a->entry[0])) {
 		    fprintf(stderr, "%s: malloc failure\n", prg);
 		    exit(1);
 		}
-		a->entry = realloc(a->entry, sizeof(a->entry[0])*nalloc);
+		a->entry = realloc(a->entry, sizeof(a->entry[0]) * nalloc);
 		if (a->entry == NULL) {
 		    fprintf(stderr, "%s: malloc failure\n", prg);
 		    exit(1);
 		}
 	    }
-	    
-	    a->entry[a->nentry].name = strdup(ent->fts_path+prefix_length);
+
+	    a->entry[a->nentry].name = strdup(ent->fts_path + prefix_length);
 	    a->entry[a->nentry].size = (zip_uint64_t)ent->fts_statp->st_size;
 	    if ((crc = compute_crc(ent->fts_accpath)) < 0) {
 		fts_close(fts);
 		return -1;
 	    }
-	    
+
 	    a->entry[a->nentry].crc = (zip_uint32_t)crc;
 	    a->nentry++;
 	    break;
@@ -386,14 +376,13 @@ list_directory(const char *name, struct archive *a)
 
 
 static int
-list_zip(const char *name, struct archive *a)
-{
+list_zip(const char *name, struct archive *a) {
     zip_t *za;
     int err;
     struct zip_stat st;
     unsigned int i;
 
-    if ((za=zip_open(name, paranoid ? ZIP_CHECKCONS : 0, &err)) == NULL) {
+    if ((za = zip_open(name, paranoid ? ZIP_CHECKCONS : 0, &err)) == NULL) {
 	zip_error_t error;
 	zip_error_init_with_code(&error, err);
 	fprintf(stderr, "%s: cannot open zip archive '%s': %s\n", prg, name, zip_error_strerror(&error));
@@ -403,16 +392,16 @@ list_zip(const char *name, struct archive *a)
 
     a->za = za;
     a->nentry = (zip_uint64_t)zip_get_num_entries(za, 0);
-    
+
     if (a->nentry == 0)
 	a->entry = NULL;
     else {
-	if ((a->nentry > SIZE_MAX/sizeof(a->entry[0])) || (a->entry=(struct entry *)malloc(sizeof(a->entry[0]) * a->nentry)) == NULL) {
+	if ((a->nentry > SIZE_MAX / sizeof(a->entry[0])) || (a->entry = (struct entry *)malloc(sizeof(a->entry[0]) * a->nentry)) == NULL) {
 	    fprintf(stderr, "%s: malloc failure\n", prg);
 	    exit(1);
 	}
 
-	for (i=0; i<a->nentry; i++) {
+	for (i = 0; i < a->nentry; i++) {
 	    zip_stat_index(za, i, 0, &st);
 	    a->entry[i].name = strdup(st.name);
 	    a->entry[i].size = st.size;
@@ -421,24 +410,24 @@ list_zip(const char *name, struct archive *a)
 		test_file(za, i, st.size, st.crc);
 	    if (paranoid) {
 		a->entry[i].comp_method = st.comp_method;
-		ef_read(za, i, a->entry+i);
+		ef_read(za, i, a->entry + i);
 		a->entry[i].comment = zip_file_get_comment(za, i, &a->entry[i].comment_length, 0);
 	    }
 	    else {
 		a->entry[i].comp_method = 0;
 		a->entry[i].n_extra_fields = 0;
 	    }
-        }
+	}
 
-        if (paranoid) {
-            int length;
+	if (paranoid) {
+	    int length;
 	    a->comment = zip_get_archive_comment(za, &length, 0);
-            a->comment_length = (size_t)length;
-        }
-        else {
-            a->comment = NULL;
-            a->comment_length = 0;
-        }
+	    a->comment_length = (size_t)length;
+	}
+	else {
+	    a->comment = NULL;
+	    a->comment_length = 0;
+	}
     }
 
     return 0;
@@ -454,39 +443,35 @@ comment_compare(const char *c1, size_t l1, const char *c2, size_t l2) {
 	return 0;
 
     if (c1 == NULL || c2 == NULL)
-        return c1 == c2;
-    
+	return c1 == c2;
+
     return memcmp(c1, c2, (size_t)l2);
 }
 
 
 static int
-compare_list(char * const name[2],
-	     const void *l[2], const zip_uint64_t n[2], int size,
-	     int (*cmp)(const void *, const void *),
-	     int (*check)(char *const name[2], const void *, const void *),
-	     void (*print)(const void *))
-{
+compare_list(char *const name[2], const void *l[2], const zip_uint64_t n[2], int size, int (*cmp)(const void *, const void *), int (*check)(char *const name[2], const void *, const void *), void (*print)(const void *)) {
     unsigned int i[2];
     int j, c;
     int diff;
 
-#define INC(k)	(i[k]++, l[k]=((const char *)l[k])+size)
-#define PRINT(k)	do {						\
-			    if (header_done==0 && verbose) {		\
-			        printf("--- %s\n+++ %s\n", name[0], name[1]); \
-				header_done = 1;			\
-			    }						\
-			    if (verbose) {				\
-			        printf("%c ", (k)?'+':'-');		\
-				print(l[k]);				\
-			    }						\
-			    diff = 1;					\
-			} while (0)
+#define INC(k) (i[k]++, l[k] = ((const char *)l[k]) + size)
+#define PRINT(k)                                          \
+    do {                                                  \
+	if (header_done == 0 && verbose) {                \
+	    printf("--- %s\n+++ %s\n", name[0], name[1]); \
+	    header_done = 1;                              \
+	}                                                 \
+	if (verbose) {                                    \
+	    printf("%c ", (k) ? '+' : '-');               \
+	    print(l[k]);                                  \
+	}                                                 \
+	diff = 1;                                         \
+    } while (0)
 
     i[0] = i[1] = 0;
     diff = 0;
-    while (i[0]<n[0] && i[1]<n[1]) {
+    while (i[0] < n[0] && i[1] < n[1]) {
 	c = cmp(l[0], l[1]);
 
 	if (c == 0) {
@@ -505,8 +490,8 @@ compare_list(char * const name[2],
 	}
     }
 
-    for (j=0; j<2; j++) {
-	while (i[j]<n[j]) {
+    for (j = 0; j < 2; j++) {
+	while (i[j] < n[j]) {
 	    PRINT(j);
 	    INC(j);
 	}
@@ -517,31 +502,29 @@ compare_list(char * const name[2],
 
 
 static int
-ef_read(zip_t *za, zip_uint64_t idx, struct entry *e)
-{
+ef_read(zip_t *za, zip_uint64_t idx, struct entry *e) {
     zip_int16_t n_local, n_central;
     zip_uint16_t i;
 
-    if ((n_local = zip_file_extra_fields_count(za, idx, ZIP_FL_LOCAL)) < 0
-        || (n_central = zip_file_extra_fields_count(za, idx, ZIP_FL_CENTRAL)) < 0) {
-        return -1;
+    if ((n_local = zip_file_extra_fields_count(za, idx, ZIP_FL_LOCAL)) < 0 || (n_central = zip_file_extra_fields_count(za, idx, ZIP_FL_CENTRAL)) < 0) {
+	return -1;
     }
-    
+
     e->n_extra_fields = (zip_uint16_t)(n_local + n_central);
-    
-    if ((e->extra_fields=(struct ef *)malloc(sizeof(e->extra_fields[0])*e->n_extra_fields)) == NULL)
+
+    if ((e->extra_fields = (struct ef *)malloc(sizeof(e->extra_fields[0]) * e->n_extra_fields)) == NULL)
 	return -1;
 
-    for (i=0; i<n_local; i++) {
+    for (i = 0; i < n_local; i++) {
 	e->extra_fields[i].name = e->name;
 	e->extra_fields[i].data = zip_file_extra_field_get(za, idx, i, &e->extra_fields[i].id, &e->extra_fields[i].size, ZIP_FL_LOCAL);
 	if (e->extra_fields[i].data == NULL)
 	    return -1;
 	e->extra_fields[i].flags = ZIP_FL_LOCAL;
     }
-    for (; i<e->n_extra_fields; i++) {
+    for (; i < e->n_extra_fields; i++) {
 	e->extra_fields[i].name = e->name;
-	e->extra_fields[i].data=zip_file_extra_field_get(za, idx, (zip_uint16_t)(i-n_local), &e->extra_fields[i].id, &e->extra_fields[i].size, ZIP_FL_CENTRAL);
+	e->extra_fields[i].data = zip_file_extra_field_get(za, idx, (zip_uint16_t)(i - n_local), &e->extra_fields[i].id, &e->extra_fields[i].size, ZIP_FL_CENTRAL);
 	if (e->extra_fields[i].data == NULL)
 	    return -1;
 	e->extra_fields[i].flags = ZIP_FL_CENTRAL;
@@ -554,8 +537,7 @@ ef_read(zip_t *za, zip_uint64_t idx, struct entry *e)
 
 
 static int
-ef_compare(char *const name[2], const struct entry *e1, const struct entry *e2)
-{
+ef_compare(char *const name[2], const struct entry *e1, const struct entry *e2) {
     struct ef *ef[2];
     zip_uint64_t n[2];
 
@@ -568,7 +550,6 @@ ef_compare(char *const name[2], const struct entry *e1, const struct entry *e2)
 }
 
 
-
 static int
 ef_order(const void *ap, const void *bp) {
     const struct ef *a, *b;
@@ -587,35 +568,33 @@ ef_order(const void *ap, const void *bp) {
 
 
 static void
-ef_print(const void *p)
-{
+ef_print(const void *p) {
     const struct ef *ef = (struct ef *)p;
     int i;
 
     printf("                    %s  ", ef->name);
     printf("%04x %c <", ef->id, ef->flags == ZIP_FL_LOCAL ? 'l' : 'c');
-    for (i=0; i<ef->size; i++)
+    for (i = 0; i < ef->size; i++)
 	printf("%s%02x", i ? " " : "", ef->data[i]);
     printf(">\n");
 }
 
 
 static int
-entry_cmp(const void *p1, const void *p2)
-{
+entry_cmp(const void *p1, const void *p2) {
     const struct entry *e1, *e2;
     int c;
 
     e1 = (struct entry *)p1;
     e2 = (struct entry *)p2;
 
-    if ((c=(ignore_case ? strcasecmp : strcmp)(e1->name, e2->name)) != 0)
+    if ((c = (ignore_case ? strcasecmp : strcmp)(e1->name, e2->name)) != 0)
 	return c;
     if (e1->size != e2->size) {
-        if (e1->size > e2->size)
-            return 1;
-        else
-            return -1;
+	if (e1->size > e2->size)
+	    return 1;
+	else
+	    return -1;
     }
     if (e1->crc != e2->crc)
 	return (int)e1->crc - (int)e2->crc;
@@ -639,7 +618,7 @@ entry_paranoia_checks(char *const name[2], const void *p1, const void *p2) {
 
     if (e1->comp_method != e2->comp_method) {
 	if (verbose) {
-	    if (header_done==0) {
+	    if (header_done == 0) {
 		printf("--- %s\n+++ %s\n", name[0], name[1]);
 		header_done = 1;
 	    }
@@ -648,11 +627,11 @@ entry_paranoia_checks(char *const name[2], const void *p1, const void *p2) {
 	    printf("+++                     %s  ", e1->name);
 	    printf("method %u\n", e2->comp_method);
 	}
-	ret =  1;
+	ret = 1;
     }
     if (comment_compare(e1->comment, e1->comment_length, e2->comment, e2->comment_length) != 0) {
 	if (verbose) {
-	    if (header_done==0) {
+	    if (header_done == 0) {
 		printf("--- %s\n+++ %s\n", name[0], name[1]);
 		header_done = 1;
 	    }
@@ -668,10 +647,8 @@ entry_paranoia_checks(char *const name[2], const void *p1, const void *p2) {
 }
 
 
-
 static void
-entry_print(const void *p)
-{
+entry_print(const void *p) {
     const struct entry *e;
 
     e = (struct entry *)p;
@@ -682,29 +659,28 @@ entry_print(const void *p)
 
 
 static int
-test_file(zip_t *za, zip_uint64_t idx, zip_uint64_t size, zip_uint32_t crc)
-{
+test_file(zip_t *za, zip_uint64_t idx, zip_uint64_t size, zip_uint32_t crc) {
     zip_file_t *zf;
     char buf[8192];
     zip_uint64_t nsize;
     zip_int64_t n;
     zip_uint32_t ncrc;
-    
-    if ((zf=zip_fopen_index(za, idx, 0)) == NULL) {
+
+    if ((zf = zip_fopen_index(za, idx, 0)) == NULL) {
 	fprintf(stderr, "%s: cannot open file %" PRIu64 " in archive: %s\n", prg, idx, zip_strerror(za));
 	return -1;
     }
 
     ncrc = (zip_uint32_t)crc32(0, NULL, 0);
     nsize = 0;
-    
-    while ((n=zip_fread(zf, buf, sizeof(buf))) > 0) {
+
+    while ((n = zip_fread(zf, buf, sizeof(buf))) > 0) {
 	nsize += (zip_uint64_t)n;
 	ncrc = (zip_uint32_t)crc32(ncrc, (const Bytef *)buf, (unsigned int)n);
     }
 
     if (n < 0) {
-	fprintf(stderr, "%s: error reading file %" PRIu64 " in archive: %s\n",	prg, idx, zip_file_strerror(zf));
+	fprintf(stderr, "%s: error reading file %" PRIu64 " in archive: %s\n", prg, idx, zip_file_strerror(zf));
 	zip_fclose(zf);
 	return -1;
     }
