@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -53,12 +53,11 @@
 
 char *prg;
 
-#define PROGRAM	"zipmerge"
+#define PROGRAM "zipmerge"
 
 #define USAGE "usage: %s [-DhIiSsV] target-zip zip...\n"
 
-char help_head[] =
-    PROGRAM " (" PACKAGE ") by Dieter Baron and Thomas Klausner\n\n";
+char help_head[] = PROGRAM " (" PACKAGE ") by Dieter Baron and Thomas Klausner\n\n";
 
 char help[] = "\n\
   -h       display this help message\n\
@@ -77,22 +76,20 @@ Copyright (C) 2004-2017 Dieter Baron and Thomas Klausner\n\
 
 #define OPTIONS "hVDiIsS"
 
-#define CONFIRM_ALL_YES		0x001
-#define CONFIRM_ALL_NO		0x002
-#define CONFIRM_SAME_YES	0x010
-#define CONFIRM_SAME_NO		0x020
+#define CONFIRM_ALL_YES 0x001
+#define CONFIRM_ALL_NO 0x002
+#define CONFIRM_SAME_YES 0x010
+#define CONFIRM_SAME_NO 0x020
 
 int confirm;
 zip_flags_t name_flags;
 
-static int confirm_replace(zip_t *, const char *, zip_uint64_t,
-			   zip_t *, const char *, zip_uint64_t);
+static int confirm_replace(zip_t *, const char *, zip_uint64_t, zip_t *, const char *, zip_uint64_t);
 static zip_t *merge_zip(zip_t *, const char *, const char *);
 
 
 int
-main(int argc, char *argv[])
-{
+main(int argc, char *argv[]) {
     zip_t *za;
     zip_t **zs;
     int c, err;
@@ -104,7 +101,7 @@ main(int argc, char *argv[])
     confirm = CONFIRM_ALL_YES;
     name_flags = 0;
 
-    while ((c=getopt(argc, argv, OPTIONS)) != -1) {
+    while ((c = getopt(argc, argv, OPTIONS)) != -1) {
 	switch (c) {
 	case 'D':
 	    name_flags |= ZIP_FL_NODIR;
@@ -139,7 +136,7 @@ main(int argc, char *argv[])
 	}
     }
 
-    if (argc < optind+2) {
+    if (argc < optind + 2) {
 	fprintf(stderr, USAGE, prg);
 	exit(2);
     }
@@ -147,13 +144,13 @@ main(int argc, char *argv[])
     tname = argv[optind++];
     argv += optind;
 
-    n = (unsigned int)(argc-optind);
-    if ((zs=(zip_t **)malloc(sizeof(zs[0])*n)) == NULL) {
+    n = (unsigned int)(argc - optind);
+    if ((zs = (zip_t **)malloc(sizeof(zs[0]) * n)) == NULL) {
 	fprintf(stderr, "%s: out of memory\n", prg);
 	exit(1);
     }
 
-    if ((za=zip_open(tname, ZIP_CREATE, &err)) == NULL) {
+    if ((za = zip_open(tname, ZIP_CREATE, &err)) == NULL) {
 	zip_error_t error;
 	zip_error_init_with_code(&error, err);
 	fprintf(stderr, "%s: can't open zip archive '%s': %s\n", prg, tname, zip_error_strerror(&error));
@@ -161,18 +158,17 @@ main(int argc, char *argv[])
 	exit(1);
     }
 
-    for (i=0; i<n; i++) {
-	if ((zs[i]=merge_zip(za, tname, argv[i])) == NULL)
+    for (i = 0; i < n; i++) {
+	if ((zs[i] = merge_zip(za, tname, argv[i])) == NULL)
 	    exit(1);
     }
 
     if (zip_close(za) < 0) {
-	fprintf(stderr, "%s: cannot write zip archive '%s': %s\n",
-		prg, tname, zip_strerror(za));
+	fprintf(stderr, "%s: cannot write zip archive '%s': %s\n", prg, tname, zip_strerror(za));
 	exit(1);
     }
 
-    for (i=0; i<n; i++)
+    for (i = 0; i < n; i++)
 	zip_close(zs[i]);
 
     exit(0);
@@ -180,9 +176,7 @@ main(int argc, char *argv[])
 
 
 static int
-confirm_replace(zip_t *za, const char *tname, zip_uint64_t it,
-		zip_t *zs, const char *sname, zip_uint64_t is)
-{
+confirm_replace(zip_t *za, const char *tname, zip_uint64_t it, zip_t *zs, const char *sname, zip_uint64_t is) {
     char line[1024];
     struct zip_stat st, ss;
 
@@ -192,13 +186,11 @@ confirm_replace(zip_t *za, const char *tname, zip_uint64_t it,
 	return 0;
 
     if (zip_stat_index(za, it, ZIP_FL_UNCHANGED, &st) < 0) {
-	fprintf(stderr, "%s: cannot stat file %"PRIu64" in '%s': %s\n",
-		prg, it, tname, zip_strerror(za));
+	fprintf(stderr, "%s: cannot stat file %" PRIu64 " in '%s': %s\n", prg, it, tname, zip_strerror(za));
 	return -1;
     }
     if (zip_stat_index(zs, is, 0, &ss) < 0) {
-	fprintf(stderr, "%s: cannot stat file %"PRIu64" in '%s': %s\n",
-		prg, is, sname, zip_strerror(zs));
+	fprintf(stderr, "%s: cannot stat file %" PRIu64 " in '%s': %s\n", prg, is, sname, zip_strerror(zs));
 	return -1;
     }
 
@@ -209,15 +201,13 @@ confirm_replace(zip_t *za, const char *tname, zip_uint64_t it,
 	    return 0;
     }
 
-    printf("replace '%s' (%"PRIu64" / %08x) in `%s'\n"
-	   "   with '%s' (%"PRIu64" / %08x) from `%s'? ",
-	   st.name, st.size, st.crc, tname,
-	   ss.name, ss.size, ss.crc, sname);
+    printf("replace '%s' (%" PRIu64 " / %08x) in `%s'\n"
+	   "   with '%s' (%" PRIu64 " / %08x) from `%s'? ",
+	   st.name, st.size, st.crc, tname, ss.name, ss.size, ss.crc, sname);
     fflush(stdout);
 
     if (fgets(line, sizeof(line), stdin) == NULL) {
-	fprintf(stderr, "%s: read error from stdin: %s\n",
-		prg, strerror(errno));
+	fprintf(stderr, "%s: read error from stdin: %s\n", prg, strerror(errno));
 	return -1;
     }
 
@@ -229,16 +219,15 @@ confirm_replace(zip_t *za, const char *tname, zip_uint64_t it,
 
 
 static zip_t *
-merge_zip(zip_t *za, const char *tname, const char *sname)
-{
+merge_zip(zip_t *za, const char *tname, const char *sname) {
     zip_t *zs;
     zip_source_t *source;
     zip_int64_t ret, idx;
     zip_uint64_t i;
     int err;
     const char *fname;
-    
-    if ((zs=zip_open(sname, 0, &err)) == NULL) {
+
+    if ((zs = zip_open(sname, 0, &err)) == NULL) {
 	zip_error_t error;
 	zip_error_init_with_code(&error, err);
 	fprintf(stderr, "%s: can't open zip archive '%s': %s\n", prg, sname, zip_error_strerror(&error));
@@ -248,25 +237,22 @@ merge_zip(zip_t *za, const char *tname, const char *sname)
 
     ret = zip_get_num_entries(zs, 0);
     if (ret < 0) {
-        fprintf(stderr, "%s: cannot get number of entries for '%s': %s\n", prg, sname, zip_strerror(za));
-        return NULL;
+	fprintf(stderr, "%s: cannot get number of entries for '%s': %s\n", prg, sname, zip_strerror(za));
+	return NULL;
     }
-    for (i=0; i<(zip_uint64_t)ret; i++) {
+    for (i = 0; i < (zip_uint64_t)ret; i++) {
 	fname = zip_get_name(zs, i, 0);
 
-	if ((idx=zip_name_locate(za, fname, name_flags)) >= 0) {
+	if ((idx = zip_name_locate(za, fname, name_flags)) >= 0) {
 	    switch (confirm_replace(za, tname, (zip_uint64_t)idx, zs, sname, i)) {
 	    case 0:
 		break;
-		
+
 	    case 1:
-		if ((source=zip_source_zip(za, zs, i, 0, 0, 0)) == NULL
-		    || zip_replace(za, (zip_uint64_t)idx, source) < 0) {
+		if ((source = zip_source_zip(za, zs, i, 0, 0, 0)) == NULL || zip_replace(za, (zip_uint64_t)idx, source) < 0) {
 		    zip_source_free(source);
-		    fprintf(stderr,
-			    "%s: cannot replace '%s' in `%s': %s\n",
-			    prg, fname, tname, zip_strerror(za));
-                    zip_close(zs);
+		    fprintf(stderr, "%s: cannot replace '%s' in `%s': %s\n", prg, fname, tname, zip_strerror(za));
+		    zip_close(zs);
 		    return NULL;
 		}
 		break;
@@ -274,9 +260,10 @@ merge_zip(zip_t *za, const char *tname, const char *sname)
 	    case -1:
 		zip_close(zs);
 		return NULL;
-		
+
 	    default:
-		fprintf(stderr,	"%s: internal error: "
+		fprintf(stderr,
+			"%s: internal error: "
 			"unexpected return code from confirm (%d)\n",
 			prg, err);
 		zip_close(zs);
@@ -284,12 +271,9 @@ merge_zip(zip_t *za, const char *tname, const char *sname)
 	    }
 	}
 	else {
-	    if ((source=zip_source_zip(za, zs, i, 0, 0, 0)) == NULL
-		|| zip_add(za, fname, source) < 0) {
+	    if ((source = zip_source_zip(za, zs, i, 0, 0, 0)) == NULL || zip_add(za, fname, source) < 0) {
 		zip_source_free(source);
-		fprintf(stderr,
-			"%s: cannot add '%s' to `%s': %s\n",
-			prg, fname, tname, zip_strerror(za));
+		fprintf(stderr, "%s: cannot add '%s' to `%s': %s\n", prg, fname, tname, zip_strerror(za));
 		zip_close(zs);
 		return NULL;
 	    }
